@@ -2,14 +2,14 @@
 AWS S3.
 """
 
-from typing import IO, Optional, Tuple
+import io
+from typing import Optional, Tuple
 
 import boto3
 import botocore
 
 from cached_path.common import _split_cloud_path
 from cached_path.schemes.scheme_client import SchemeClient
-from cached_path.tqdm import Tqdm
 
 
 class S3Client(SchemeClient):
@@ -30,27 +30,30 @@ class S3Client(SchemeClient):
         else:
             s3_resource = session.resource("s3")
         self.s3_object = s3_resource.Object(bucket_name, s3_path)
+        self._loaded = False
+
+    def load(self):
+        if not self._loaded:
+            try:
+                self.s3_object.load()
+                self._loaded = True
+            except botocore.exceptions.ClientError as exc:
+                if int(exc.response["Error"]["Code"]) == 404:
+                    raise FileNotFoundError("file {} not found".format(self.resource))
+                else:
+                    raise
 
     def get_etag(self) -> Optional[str]:
-        try:
-            self.s3_object.load()
-        except botocore.exceptions.ClientError as exc:
-            if int(exc.response["Error"]["Code"]) == 404:
-                raise FileNotFoundError("file {} not found".format(self.resource))
-            else:
-                raise
+        self.load()
         return self.s3_object.e_tag
 
-    def get_resource(self, temp_file: IO) -> None:
-        progress = Tqdm.tqdm(
-            unit="iB",
-            unit_scale=True,
-            unit_divisor=1024,
-            total=self.s3_object.content_length,
-            desc="downloading",
-        )
-        self.s3_object.download_fileobj(temp_file, Callback=progress.update)
-        progress.close()
+    def get_size(self) -> Optional[int]:
+        self.load()
+        return self.s3_object.content_length
+
+    def get_resource(self, temp_file: io.BufferedWriter) -> None:
+        self.load()
+        self.s3_object.download_fileobj(temp_file)
 
     @staticmethod
     def split_s3_path(url: str) -> Tuple[str, str]:
